pub struct OwnableSpec;Implementations
Sourceimpl OwnableSpec
impl OwnableSpec
Sourcepub const fn spec_xdr_get_owner() -> [u8; 184]
pub const fn spec_xdr_get_owner() -> [u8; 184]
Returns Some(Address) if ownership is set, or None if ownership has
been renounced.
Arguments
e- Access to the Soroban environment.
Sourceimpl OwnableSpec
impl OwnableSpec
Sourcepub const fn spec_xdr_transfer_ownership() -> [u8; 1008]
pub const fn spec_xdr_transfer_ownership() -> [u8; 1008]
Initiates a 2-step ownership transfer to a new address.
Requires authorization from the current owner. The new owner must later
call accept_ownership() to complete the transfer.
Arguments
e- Access to the Soroban environment.new_owner- The proposed new owner.live_until_ledger- Ledger number until which the new owner can accept. A value of0cancels any pending transfer.
Errors
OwnableError::OwnerNotSet- If the owner is not set.crate::role_transfer::RoleTransferError::NoPendingTransfer- If trying to cancel a transfer that doesn’t exist.crate::role_transfer::RoleTransferError::InvalidLiveUntilLedger- If the specified ledger is in the past.crate::role_transfer::RoleTransferError::InvalidPendingAccount- If the specified pending account is not the same as the providednewaddress.
Notes
- Authorization for the current owner is required.
Sourceimpl OwnableSpec
impl OwnableSpec
Sourcepub const fn spec_xdr_accept_ownership() -> [u8; 340]
pub const fn spec_xdr_accept_ownership() -> [u8; 340]
Accepts a pending ownership transfer.
Arguments
e- Access to the Soroban environment.
Errors
crate::role_transfer::RoleTransferError::NoPendingTransfer- If there is no pending transfer to accept.
Events
- topics -
["ownership_transfer_completed"] - data -
[new_owner: Address]
Sourceimpl OwnableSpec
impl OwnableSpec
Sourcepub const fn spec_xdr_renounce_ownership() -> [u8; 432]
pub const fn spec_xdr_renounce_ownership() -> [u8; 432]
Renounces ownership of the contract.
Permanently removes the owner, disabling all functions gated by
#[only_owner].
Arguments
e- Access to the Soroban environment.
Errors
OwnableError::TransferInProgress- If there is a pending ownership transfer.OwnableError::OwnerNotSet- If the owner is not set.
Notes
- Authorization for the current owner is required.