Module role_transfer

Module role_transfer 

This module only acts as a utility crate for Access Control and Ownable. It is not intended to be used directly.

Structs

PendingTransfer
Stores the pending role holder and the explicit deadline for acceptance.

Enums

RoleTransferError

Statics

__SPEC_XDR_TYPE_ROLETRANSFERERROR

Functions

accept_transfer
Completes the role transfer if authorization is provided by the pending role holder. Pending role holder is retrieved from the storage.
has_active_pending_transfer
Returns true if the given pending-transfer key holds an active (non-expired) PendingTransfer.
transfer_role
Initiates the role transfer. If live_until_ledger == 0, cancels the pending transfer.