pub fn accept_transfer<T, U>(
e: &Env,
active_key: &T,
pending_key: &U,
) -> AddressExpand description
Completes the role transfer if authorization is provided by the pending role holder. Pending role holder is retrieved from the storage.
Arguments
e- Access to the Soroban environment.active_key- Storage key for the current role holder.pending_key- Storage key for the pending role holder.
Errors
RoleTransferError::NoPendingTransfer- If there is no pending transfer to accept.RoleTransferError::TransferExpired- If the current ledger is past thelive_until_ledgerstored inPendingTransfer. The deadline is checked explicitly here, so it is enforced even if the storage entry is still alive due to the network minimum TTL or a permissionlessextend_ttlcall.