pub fn renounce_admin(e: &Env)Expand description
Allows the current admin to renounce their role, making the contract permanently admin-less. This is useful for decentralization purposes or when the admin role is no longer needed. Once the admin is renounced, it cannot be reinstated.
Arguments
e- Access to Soroban environment.
Errors
AccessControlError::AdminNotSet- If no admin account is set.AccessControlError::TransferInProgress- If there is a pending admin transfer.
Events
- topics -
["admin_renounced", admin: Address] - data -
[]
Notes
- Authorization for the current admin is required.