This module only acts as a utility crate for Access Control and Ownable.
It is not intended to be used directly.
Structs
- Pending
Transfer - Stores the pending role holder and the explicit deadline for acceptance.
Enums
Statics
Functions
- accept_
transfer - Completes the role transfer if authorization is provided by the pending role holder. Pending role holder is retrieved from the storage.
- has_
active_ pending_ transfer - Returns
trueif the given pending-transfer key holds an active (non-expired)PendingTransfer. - transfer_
role - Initiates the role transfer. If
live_until_ledger == 0, cancels the pending transfer.