Module role_transfer

This module only acts as a utility crate for Access Control and Ownable. It is not intended to be used directly.

Enums

RoleTransferError

Statics

__SPEC_XDR_TYPE_ROLETRANSFERERROR

Functions

accept_transfer
Completes the role transfer if authorization is provided by the pending role holder. Pending role holder is retrieved from the storage.
transfer_role
Initiates the role transfer. If live_until_ledger == 0, cancels the pending transfer.